@@ -6,8 +6,8 @@
 # "License"); you may not use this file except in compliance
 # with the License.  You may obtain a copy of the License at
 #
-#     http://www.apache.org/licenses/LICENSE-2.0
 #
+#     http://www.apache.org/licenses/LICENSE-2.0
 #
 #
 # Unless required by applicable law or agreed to in writing,
@@ -18,16 +18,12 @@
 # under the License.
 
 from aliyunsdkcore.request import RpcRequest
+
 class DeleteDocIndexRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'imm', '2017-09-06', 'DeleteDocIndex','imm')
-
-	def get_Set(self):
-		return self.get_query_params().get('Set')
-
-	def set_Set(self,Set):
-		self.add_query_param('Set',Set)
+		RpcRequest.__init__(self, 'imm', '2017-09-06', 'DeleteDocIndex')
+		self.set_method('POST')
 
 	def get_Project(self):
 		return self.get_query_params().get('Project')
@@ -39,4 +35,10 @@ class DeleteDocIndexRequest(RpcRequest):
 		return self.get_query_params().get('UniqueId')
 
 	def set_UniqueId(self,UniqueId):
-		self.add_query_param('UniqueId',UniqueId)
\ No newline at end of file
+		self.add_query_param('UniqueId',UniqueId)
+
+	def get_Set(self):
+		return self.get_query_params().get('Set')
+
+	def set_Set(self,Set):
+		self.add_query_param('Set',Set)
\ No newline at end of file
