@@ -22,7 +22,7 @@ from aliyunsdkcore.request import RpcRequest
 class ListImageJobsRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'imm', '2017-09-06', 'ListImageJobs','imm')
+		RpcRequest.__init__(self, 'imm', '2017-09-06', 'ListImageJobs')
 		self.set_method('POST')
 
 	def get_MaxKeys(self):
